@@ -263,12 +263,14 @@ def to_datetime(
         r_str: bool = False,
         error_is_none: bool = False,
         tz: Optional[Union[str, timezone]] = None,
-        default_tz: Union[str, timezone] = 'UTC+8'  # 默认时区为 UTC+8
+        default_tz: Union[str, timezone] = None
 ) -> Union[datetime, str, None]:
     """
     将字符串或时间戳转换为 datetime 对象，支持时区处理。
     error_is_none : 当发生错误的时候，是否返回 None
     """
+    # 默认时区为 +08:00
+    default_tz = default_tz or '+08:00'
 
     def get_tz(tz_info: Union[str, timezone]) -> timezone:
         """将时区信息转换为timezone对象"""
@@ -276,23 +278,30 @@ def to_datetime(
             return tz_info
         if not isinstance(tz_info, str):
             raise ValueError(f"无效的时区格式: {tz_info}")
-
         tz_str = tz_info.upper()
         if tz_str == "UTC":
             return timezone.utc
-
+        # 处理纯偏移格式，如+07:00、-05:30
+        offset_match = re.match(r"^([+-])(\d{1,2}):(\d{2})$", tz_str)
+        if offset_match:
+            sign = offset_match.group(1)
+            hours = int(offset_match.group(2))
+            minutes = int(offset_match.group(3))
+            # 计算总偏移小时数
+            total_hours = hours + minutes / 60
+            if sign == "-":
+                total_hours = -total_hours
+            return timezone(timedelta(hours=total_hours))
         # 处理GMT格式，如GMT+08:00或GMT-5
         gmt_match = re.match(r"GMT([+-]\d{1,2})(:\d{2})?$", tz_str)
         if gmt_match:
             hours = int(gmt_match.group(1))
             return timezone(timedelta(hours=hours))
-
         # 处理UTC格式，如UTC+8或UTC-05:00
         utc_match = re.match(r"UTC([+-]\d{1,2})(:\d{2})?$", tz_str)
         if utc_match:
             hours = int(utc_match.group(1))
             return timezone(timedelta(hours=hours))
-
         raise ValueError(f"不支持的时区格式: {tz_info}")
 
     use_default_time = False
@@ -384,7 +393,8 @@ def to_datetime(
 def to_datetime_str(s: Any = None,
                     pattern: str = None,
                     pattern_str: str = None,
-                    tz: Optional[Union[str, timezone]] = None) -> datetime | str:
+                    tz: Optional[Union[str, timezone]] = None,
+                    default_tz: Union[str, timezone] = None) -> datetime | str:
     """
     将 s 先转成 datetime, 然后再转成字符串
 
@@ -392,7 +402,7 @@ def to_datetime_str(s: Any = None,
     :param precision: 小数部分保留的位数（多余部分直接截断）
     :return: 转换后的 float 值
     """
-    r_s = to_datetime(s, pattern=pattern, tz=tz, r_str=False)
+    r_s = to_datetime(s, pattern=pattern, tz=tz, r_str=False, default_tz=default_tz)
     return r_s.isoformat() if pattern_str is None else r_s.strftime(pattern_str)
 
 
@@ -401,6 +411,21 @@ def to_datetime_format(s: Any = None,
     return to_datetime_str(s, pattern=None, pattern_str=pattern_str, tz=None)
 
 
+def to_datetime_format__6(s: Any = None,
+                          pattern_str: str = "%Y-%m-%d %H:%M:%S") -> datetime | str:
+    return to_datetime_str(s, pattern=None, pattern_str=pattern_str, tz='-06:00')
+
+
+def to_datetime_format_7(s: Any = None,
+                         pattern_str: str = "%Y-%m-%d %H:%M:%S") -> datetime | str:
+    return to_datetime_str(s, pattern=None, pattern_str=pattern_str, tz='+07:00')
+
+
+def to_datetime_format_8(s: Any = None,
+                         pattern_str: str = "%Y-%m-%d %H:%M:%S") -> datetime | str:
+    return to_datetime_str(s, pattern=None, pattern_str=pattern_str, tz='+08:00')
+
+
 # 时间加减
 def to_datetime_add(s: Any = None,
                     days: int = 0,
